==> foundation-ui-components-1.11.0.tgz: package/src/common/typography/Typography.styled.tsx <==
import { styled, ColorUtils } from '@nuskin/foundation-theme';
import { NsTypographyProps } from './types.d';

const { paletteColor } = ColorUtils;

const variantStyles = {
    h1: {
        'font-size': '42px',
        'line-height': '48px',
        'letter-spacing': '0px',
        margin: '0px',
    },
    h2: {
        'font-size': '36px',
        'line-height': '42px',
        'letter-spacing': '0px',
        margin: '0px',
    },
    h3: {
        'font-size': '32px',
        'line-height': '38px',
        'letter-spacing': '0px',
        margin: '0px',
    },
    h4: {
        'font-size': '26px',
        'line-height': '34px',
        'letter-spacing': '0px',
        margin: '0px',
    },
    h5: {
        'font-size': '22px',
        'line-height': '28px',
        'letter-spacing': '0px',
        'font-weight': '700',
        margin: '0px',
    },
    h6: {
        'font-size': '18px',
        'line-height': '24px',
        'letter-spacing': '0px',
        'font-weight': '600',
        margin: '0px',
    },
    'title-l': {
        'font-size': '22px',
        'line-height': '28px',
        'letter-spacing': '2px',
        'font-weight': '700',
        margin: '0px',
    },
    'title-m': {
        'font-size': '16px',
        'line-height': '20px',
        'letter-spacing': '4px',
        'font-weight': '700',
        margin: '0px',
    },
    'title-s': {
        'font-size': '16px',
        'line-height': '16px',
        'letter-spacing': '4px',
        'font-weight': '700',
        margin: '0px',
    },
    'label-l': {
        'font-size': '20px',
        'line-height': '26px',
        'letter-spacing': '0px',
        'font-weight': '600',
        margin: '8px',
    },
    'label-m': {
        'font-size': '16px',
        'line-height': '22px',
        'letter-spacing': '0px',
        'font-weight': '600',
        margin: '8px',
    },
    'label-s': {
        'font-size': '14px',
        'line-height': '20px',
        'letter-spacing': '0px',
        'font-weight': '700',
        margin: '6px',
    },
    'body-xl': {
        'font-size': '18px',
        'line-height': '22px',
        'letter-spacing': '0px',
        margin: '22px',
    },
    'body-l': {
        'font-size': '16px',
        'line-height': '22px',
        'letter-spacing': '0px',
        margin: '20px',
    },
    'body-m': {
        'font-size': '14px',
        'line-height': '20px',
        'letter-spacing': '0px',
        margin: '18px',
    },
    'body-s': {
        'font-size': '12px',
        'line-height': '16px',
        'letter-spacing': '1px',
        margin: '16px',
    },
    'body-xs': {
        'font-size': '10px',
        'line-height': '14px',
        'letter-spacing': '2px',
        margin: '14px',
    },
    CTA: {
        'font-size': '14px',
        'line-height': '20px',
        'letter-spacing': '0.14px',
        'font-weight': '600',
        margin: '0px',
    },
};

const fontWeightMap = {
    light: 300,
    normal: 400,
    bold: 600,
};

export const StyledTypography = styled.div<NsTypographyProps>`
    font-family: Inter;
    color: ${({ color, colorOverride }) => (colorOverride?.startsWith('#') ? colorOverride : paletteColor(color))};
    font-weight: ${({ weight = 'normal' }) => fontWeightMap[weight]};
    ${({ variant = 'h1' }) => variantStyles[variant]};
    text-decoration-line: ${({ decoration }) => decoration};
`;

==> foundation-ui-components-1.15.0.tgz: package/src/common/typography/Typography.styled.tsx <==
import { styled, ColorUtils } from '@nuskin/foundation-theme';
import { NsTypographyProps } from './types.d';

const { paletteColor } = ColorUtils;

const variantStyles = {
    h1: {
        'font-size': '42px',
        'line-height': '48px',
        'letter-spacing': '0px',
        margin: '0px',
    },
    h2: {
        'font-size': '36px',
        'line-height': '42px',
        'letter-spacing': '0px',
        margin: '0px',
    },
    h3: {
        'font-size': '32px',
        'line-height': '38px',
        'letter-spacing': '0px',
        margin: '0px',
    },
    h4: {
        'font-size': '26px',
        'line-height': '34px',
        'letter-spacing': '0px',
        margin: '0px',
    },
    h5: {
        'font-size': '22px',
        'line-height': '28px',
        'letter-spacing': '0px',
        'font-weight': '700',
        margin: '0px',
    },
    h6: {
        'font-size': '18px',
        'line-height': '24px',
        'letter-spacing': '0px',
        'font-weight': '600',
        margin: '0px',
    },
    'title-l': {
        'font-size': '22px',
        'line-height': '28px',
        'letter-spacing': '2px',
        'font-weight': '700',
        margin: '0px',
    },
    'title-m': {
        'font-size': '16px',
        'line-height': '20px',
        'letter-spacing': '4px',
        'font-weight': '700',
        margin: '0px',
    },
    'title-s': {
        'font-size': '16px',
        'line-height': '16px',
        'letter-spacing': '4px',
        'font-weight': '700',
        margin: '0px',
    },
    'label-l': {
        'font-size': '20px',
        'line-height': '26px',
        'letter-spacing': '0px',
        'font-weight': '600',
        margin: '8px',
    },
    'label-m': {
        'font-size': '16px',
        'line-height': '22px',
        'letter-spacing': '0px',
        'font-weight': '600',
        margin: '8px',
    },
    'label-s': {
        'font-size': '14px',
        'line-height': '20px',
        'letter-spacing': '0px',
        'font-weight': '700',
        margin: '6px',
    },
    'body-xl': {
        'font-size': '18px',
        'line-height': '22px',
        'letter-spacing': '0px',
        margin: '22px',
    },
    'body-l': {
        'font-size': '16px',
        'line-height': '22px',
        'letter-spacing': '0px',
        margin: '20px',
    },
    'body-m': {
        'font-size': '14px',
        'line-height': '20px',
        'letter-spacing': '0px',
        margin: '18px',
    },
    'body-s': {
        'font-size': '12px',
        'line-height': '16px',
        'letter-spacing': '1px',
        margin: '16px',
    },
    'body-xs': {
        'font-size': '10px',
        'line-height': '14px',
        'letter-spacing': '2px',
        margin: '14px',
    },
    CTA: {
        'font-size': '14px',
        'line-height': '20px',
        'letter-spacing': '0.14px',
        'font-weight': '600',
        margin: '0px',
    },
};

const fontWeightMap = {
    light: 300,
    normal: 400,
    bold: 600,
};

export const StyledTypography = styled('div')<NsTypographyProps>(
    ({ theme, weight = 'normal', variant = 'h1', noSpacing, decoration, color, colorOverride }) => {
        const fontStyles = variantStyles[variant];
        if (noSpacing) {
            fontStyles.margin = '0px';
        }
        return {
            ...fontStyles,
            fontFamily: 'Inter',
            textDecorationLine: decoration,
            fontWeight: fontWeightMap[weight],
            color: colorOverride?.startsWith('#') ? colorOverride : paletteColor(color)({ theme }),
        };
    }
);
